@@ -1,8 +1,8 @@
 #!/usr/local/bin/perl
 # $File: //member/autrijus/Encode-HanConvert/bin/b2g.pl $ $Author: autrijus $
-# $Revision: #12 $ $Change: 10738 $ $DateTime: 2004/06/03 20:56:41 $
+# $Revision: #14 $ $Change: 10740 $ $DateTime: 2004/06/03 22:02:31 $
 
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 =head1 NAME
 
@@ -58,7 +58,7 @@ use Encode::HanConvert;
 
 if (UTF8 and $] >= 5.008) { binmode(STDIN, ':utf8'); binmode(STDOUT, ':utf8') }
 
-my $KEYS = join('|', sort { length($b) <=> length($a) } keys %{+MAP}) if DICT;
+my $KEYS = join('|', map quotemeta, sort { length($b) <=> length($a) } keys %{+MAP}) if DICT;
 my $MAP  = +MAP if DICT;
 
 while (<>) {
@@ -335,6 +335,28 @@ use constant MAP => DICT && {
 'λԪ' => 'ֽ',
 '' => '',
 '' => '',
+'' => '',
+'' => '',
+'' => '',
+'' => '',
+'ד' => 'ٝ',
+'ד' => 'ٝ',
+'ד~' => 'ٝ~',
+'ǰ' => '̨ǰ',
+'' => '̨',
+'' => '̨',
+'_' => '̨',
+'_' => '̨',
+'_' => '̨',
+'_|' => '̨|',
+'UL' => '̨L',
+'I' => '',
+'I' => '',
+'Il' => 'l',
+'I' => '',
+'I' => '',
+'' => '',
+'ĸ' => 'ĸ',
 ) };
 
 __END__
