@@ -1,8 +1,8 @@
 #!/usr/local/bin/perl
 # $File: //member/autrijus/Encode-HanConvert/bin/g2b.pl $ $Author: autrijus $
-# $Revision: #11 $ $Change: 10738 $ $DateTime: 2004/06/03 20:56:41 $
+# $Revision: #13 $ $Change: 10740 $ $DateTime: 2004/06/03 22:02:31 $
 
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 =head1 NAME
 
@@ -58,7 +58,7 @@ use Encode::HanConvert;
 
 if (UTF8 and $] >= 5.008) { binmode(STDIN, ':utf8'); binmode(STDOUT, ':utf8') }
 
-my $KEYS = join('|', sort { length($b) <=> length($a) } keys %{+MAP}) if DICT;
+my $KEYS = join('|', map quotemeta, sort { length($b) <=> length($a) } keys %{+MAP}) if DICT;
 my $MAP  = +MAP if DICT;
 
 while (<>) {
@@ -69,7 +69,7 @@ while (<>) {
 }
 
 use constant MAP => DICT && {
-    map { UTF8 ? Encode::decode(big5 => $_) : $_ } reverse (
+    map { UTF8 ? Encode::decode(big5 => $_) : quotemeta($_) } reverse (
 'A' => 'H',
 'AӺ' => 'HӺ',
 'EEk' => 'EE',
@@ -385,6 +385,27 @@ use constant MAP => DICT && {
 '줸' => 'r`',
 '쵲' => '챵',
 'KX' => 'fO',
+'u' => '',
+'v' => '',
+'y' => '',
+'z' => '',
+'g' => '٬',
+'g|' => 'ٹ|',
+'g' => 'ٵ',
+'ie' => 'xe',
+'iO' => 'xO',
+'iW' => 'xW',
+'OW' => 'xW',
+'O_' => 'x_',
+'On' => 'xn',
+'䭷' => 'x',
+'ѯ' => '',
+'ѥ]' => ']',
+'ѱ' => '',
+'' => '',
+'' => '',
+'' => 'Z',
+'' => 'Z',
 ) }
 __END__
 
